@@ -383,23 +383,23 @@ def calc_fragment_mz_values_for_same_nAA(
         lambda x: [int(s) for s in x if len(s)>0]
     ).values
 
-    if 'mod_deltas' in df_group.columns:
-        mod_delta_list = df_group.mod_deltas.str.split(';').apply(
+    if 'aa_mass_diffs' in df_group.columns:
+        mod_diff_list = df_group.aa_mass_diffs.str.split(';').apply(
             lambda x: [float(m) for m in x if len(m)>0]
         ).values
-        mod_delta_site_list = df_group.mod_delta_sites.str.split(';').apply(
+        mod_diff_site_list = df_group.aa_mass_diff_sites.str.split(';').apply(
             lambda x: [int(s) for s in x if len(s)>0]
         ).values
     else:
-        mod_delta_list = None
-        mod_delta_site_list = None
+        mod_diff_list = None
+        mod_diff_site_list = None
     (
         b_mass, y_mass, pepmass
     ) = calc_b_y_and_peptide_masses_for_same_len_seqs(
         df_group.sequence.values.astype('U'), 
         mod_list, site_list,
-        mod_delta_list,
-        mod_delta_site_list
+        mod_diff_list,
+        mod_diff_site_list
     )
     b_mass = b_mass.reshape(-1)
     y_mass = y_mass.reshape(-1)
@@ -420,16 +420,15 @@ def calc_fragment_mz_values_for_same_nAA(
             break
 
     mz_values = []
-    # Neutral masses also considered for future uses
-    # for example when searching with spectral with neutral masses
-    for charged_frag_type in charged_frag_types:
-        if charged_frag_type == 'b':
-            mz_values.append(b_mass)
-        elif charged_frag_type == 'y':
-            mz_values.append(y_mass)
-
     add_proton = MASS_PROTON
     for charged_frag_type in charged_frag_types:
+        # Neutral masses also considered for future uses
+        if charged_frag_type == 'b':
+            mz_values.append(b_mass)
+            continue
+        elif charged_frag_type == 'y':
+            mz_values.append(y_mass)
+            continue
         frag_type, charge = parse_charged_frag_type(charged_frag_type)
         if frag_type == 'b':
             _mass = b_mass/charge + add_proton
@@ -595,7 +594,7 @@ def flatten_fragments(
     Returns
     -------
     pd.DataFrame
-        precursor dataframe whith reindexed `frag_start_idx` and `frag_stop_idx` columns
+        precursor dataframe with added `flat_frag_start_idx` and `flat_frag_stop_idx` columns
     pd.DataFrame
         fragment dataframe with columns: `mz`, `intensity`, `type`, `number`, 
         `charge` and `loss_type`, where each column refers to:
@@ -667,8 +666,9 @@ def flatten_fragments(
             precursor_df.frag_stop_idx.values
         ).reshape(-1)
 
-    precursor_new_df = precursor_df.copy()
-    precursor_new_df[['frag_start_idx','frag_stop_idx']] *= len(fragment_mz_df.columns)
+    precursor_df['flat_frag_start_idx'] = precursor_df.frag_start_idx
+    precursor_df['flat_frag_stop_idx'] = precursor_df.frag_stop_idx
+    precursor_df[['flat_frag_start_idx','flat_frag_stop_idx']] *= len(fragment_mz_df.columns)
 
     
     if use_intensity:
@@ -682,8 +682,8 @@ def flatten_fragments(
         ) | (
             exclude_not_top_k(
                 frag_df.intensity.values, keep_top_k_fragments,
-                precursor_new_df.frag_start_idx.values,
-                precursor_new_df.frag_stop_idx.values,
+                precursor_df.flat_frag_start_idx.values,
+                precursor_df.flat_frag_stop_idx.values,
             )
         )
     )
@@ -696,10 +696,10 @@ def flatten_fragments(
     cum_sum_tresh = np.zeros(shape=len(excluded)+1, dtype=np.int64)
     cum_sum_tresh[1:] = np.cumsum(excluded)
 
-    precursor_new_df['frag_start_idx'] -= cum_sum_tresh[precursor_new_df.frag_start_idx.values]
-    precursor_new_df['frag_stop_idx'] -= cum_sum_tresh[precursor_new_df.frag_stop_idx.values]
+    precursor_df['flat_frag_start_idx'] -= cum_sum_tresh[precursor_df.flat_frag_start_idx.values]
+    precursor_df['flat_frag_stop_idx'] -= cum_sum_tresh[precursor_df.flat_frag_stop_idx.values]
 
-    return precursor_new_df, frag_df
+    return precursor_df, frag_df
 
 @nb.njit()
 def compress_fragment_indices(frag_idx):
