@@ -13,36 +13,36 @@ from alphabase.constants.modification import (
 )
 from alphabase.constants.element import MASS_H2O
 
-def calc_delta_modification_mass(
+def calc_diff_modification_mass(
     pep_len:int,
-    mass_deltas:List[float],
-    mass_delta_sites:List[int]
+    mass_diffs:List[float],
+    mass_diff_sites:List[int]
 )->np.ndarray:
     '''
     For open-search, we may also get modification 
-    mass deltas other than mod names. This function calculate
-    modification masses from these delta masses.
+    mass diffs other than mod names. This function calculate
+    modification masses from these diff masses.
     
     Parameters
     ----------
     pep_len : int
         nAA
     
-    mass_deltas : List[float]
-        mass deltas on the peptide
+    mass_diffs : List[float]
+        mass diffs on the peptide
 
-    mass_delta_sites : List[int]
-        localized sites of corresponding mass deltas
+    mass_diff_sites : List[int]
+        localized sites of corresponding mass diffs
 
     Returns
     -------
     np.ndarray
         1-D array with length=`peplen`.
-        Masses of modifications (mass deltas) through the peptide,
+        Masses of modifications (mass diffs) through the peptide,
         `0` if sites has no modifications
     '''
     masses = np.zeros(pep_len)
-    for site, mass in zip(mass_delta_sites, mass_deltas):
+    for site, mass in zip(mass_diff_sites, mass_diffs):
         if site == 0:
             masses[site] += mass
         elif site == -1:
@@ -51,16 +51,16 @@ def calc_delta_modification_mass(
             masses[site-1] += mass
     return masses
 
-def calc_mod_delta_masses_for_same_len_seqs(
+def calc_mod_diff_masses_for_same_len_seqs(
     nAA:int, 
-    mod_deltas_list:List[List[float]], 
+    aa_mass_diffs_list:List[List[float]], 
     mod_sites_list:List[List[int]]
 )->np.ndarray:
     '''
-    Calculate delta modification masses for the given peptide length (`nAA`), 
+    Calculate diff modification masses for the given peptide length (`nAA`), 
     For open-search, we may also get modification 
-    mass deltas other than mod names. This function calculate
-    modification masses from these delta masses.
+    mass diffs other than mod names. This function calculate
+    modification masses from these diff masses.
     
     Parameters
     ----------
@@ -84,25 +84,25 @@ def calc_mod_delta_masses_for_same_len_seqs(
         Masses of modifications through all the peptides, 
         `0` if sites has no modifications
     '''
-    masses = np.zeros((len(mod_deltas_list),nAA))
-    for i, (mod_deltas, mod_sites) in enumerate(
-        zip(mod_deltas_list, mod_sites_list)
+    masses = np.zeros((len(aa_mass_diffs_list),nAA))
+    for i, (aa_mass_diffs, mod_sites) in enumerate(
+        zip(aa_mass_diffs_list, mod_sites_list)
     ):
-        for mod_delta, site in zip(mod_deltas, mod_sites): 
+        for mod_diff, site in zip(aa_mass_diffs, mod_sites): 
             if site == 0:
-                masses[i,site] += mod_delta
+                masses[i,site] += mod_diff
             elif site == -1:
-                masses[i,site] += mod_delta
+                masses[i,site] += mod_diff
             else:
-                masses[i,site-1] += mod_delta
+                masses[i,site-1] += mod_diff
     return masses
 
 def calc_b_y_and_peptide_mass(
     sequence: str,
     mod_names: List[str],
     mod_sites: List[int],
-    mod_deltas: List[float] = None,
-    mod_delta_sites: List[int] = None,
+    aa_mass_diffs: List[float] = None,
+    aa_mass_diff_sites: List[int] = None,
 )->Tuple[np.ndarray,np.ndarray,float]:
     '''
     It is highly recommend to use 
@@ -114,9 +114,9 @@ def calc_b_y_and_peptide_mass(
         len(sequence), mod_names, mod_sites
     )
     residue_masses += mod_masses
-    if mod_deltas is not None:
-        mod_masses = calc_delta_modification_mass(
-            len(sequence), mod_deltas, mod_delta_sites
+    if aa_mass_diffs is not None:
+        mod_masses = calc_diff_modification_mass(
+            len(sequence), aa_mass_diffs, aa_mass_diff_sites
         )
         residue_masses += mod_masses
     #residue_masses = residue_masses[np.newaxis, ...]
@@ -130,7 +130,7 @@ def calc_b_y_and_peptide_mass(
 def calc_peptide_masses_for_same_len_seqs(
     sequences: np.ndarray,
     mod_list: List[str],
-    mod_delta_list: List[str]=None
+    mod_diff_list: List[str]=None
 )->np.ndarray:
     '''
     Calculate peptide masses for peptide sequences with same lengths.
@@ -145,9 +145,9 @@ def calc_peptide_masses_for_same_len_seqs(
         list of modifications, 
         e.g. `['Oxidation@M;Phospho@S','Phospho@S;Deamidated@N']`
 
-    mass_delta_list : List[str]
+    mass_diff_list : List[str]
     
-        List of modifications as mass deltas,
+        List of modifications as mass diffs,
         e.g. `['15.9xx;79.9xxx','79.9xx;0.98xx']`
     
     Returns
@@ -165,11 +165,11 @@ def calc_peptide_masses_for_same_len_seqs(
             mod_masses[i] = calc_modification_mass_sum(
                 mods.split(';')
             )
-    if mod_delta_list is not None:
-        for i, mass_deltas in enumerate(mod_delta_list):
-            if len(mass_deltas) > 0:
+    if mod_diff_list is not None:
+        for i, mass_diffs in enumerate(mod_diff_list):
+            if len(mass_diffs) > 0:
                 mod_masses[i] += np.sum([
-                    float(mass) for mass in mass_deltas.split(';')
+                    float(mass) for mass in mass_diffs.split(';')
                 ])
     return seq_masses+mod_masses
     
@@ -178,8 +178,8 @@ def calc_b_y_and_peptide_masses_for_same_len_seqs(
     sequences: np.ndarray,
     mod_list: List[List[str]],
     site_list: List[List[int]],
-    mod_delta_list: List[List[float]]=None,
-    mod_delta_site_list: List[List[int]]=None,
+    mod_diff_list: List[List[float]]=None,
+    mod_diff_site_list: List[List[int]]=None,
 )->Tuple[np.ndarray,np.ndarray,np.ndarray]:
     '''
     Calculate b/y fragment masses and peptide masses 
@@ -200,12 +200,12 @@ def calc_b_y_and_peptide_masses_for_same_len_seqs(
         list of modification sites
         corresponding to `mod_list`, e.g. `[[3,6],[4,17]]`
 
-    mod_delta_list : List[List[float]]
+    mod_diff_list : List[List[float]]
         list of modifications, 
         e.g. `[[15.994915,79.966331],[79.966331,0.984016]]` 
 
-    mod_delta_site_list : List[List[int]]
-        list of modification mass delta sites
+    mod_diff_site_list : List[List[int]]
+        list of modification mass diff sites
         corresponding to `mod_list`, e.g. `[[3,6],[4,17]]`
     
     Returns
@@ -231,17 +231,17 @@ def calc_b_y_and_peptide_masses_for_same_len_seqs(
     #             sites,
     #         )
     mod_masses = calc_mod_masses_for_same_len_seqs(nAA, mod_list, site_list)
-    if mod_delta_list is not None:
-        mod_masses += calc_mod_delta_masses_for_same_len_seqs(
-            nAA, mod_delta_list, mod_delta_site_list
+    if mod_diff_list is not None:
+        mod_masses += calc_mod_diff_masses_for_same_len_seqs(
+            nAA, mod_diff_list, mod_diff_site_list
         )
-        # for i, (mass_deltas, sites) in enumerate(zip(
-        #     mass_delta_list, mass_delta_site_list
+        # for i, (mass_diffs, sites) in enumerate(zip(
+        #     mass_diff_list, mass_diff_site_list
         # )):
-        #     if len(mass_deltas) != 0:
-        #         mod_masses[i,:] += calc_delta_modification_mass(
+        #     if len(mass_diffs) != 0:
+        #         mod_masses[i,:] += calc_diff_modification_mass(
         #             seq_len, 
-        #             mass_deltas, 
+        #             mass_diffs, 
         #             sites,
         #         )
     aa_masses += mod_masses
