@@ -27,17 +27,13 @@ def parse_ap(precursor):
     sites = []
     string = ""
 
-    if modseq[0] == 'a':
+    for i in range(len(modseq)):
+        if modseq[i].isupper():
+            break
+    if i > 0:
         sites.append('0')
-        mods.append('a')
-        modseq = modseq[1:]
-    elif modseq.startswith('tmt'):
-        for l in range(3, len(modseq)):
-            if modseq[l].isupper():
-                break
-        sites.append('0')
-        mods.append(modseq[:l])
-        modseq = modseq[l:]
+        mods.append(modseq[:i])
+        modseq = modseq[i:]
 
     for i in modseq:
         string += i
@@ -50,15 +46,6 @@ def parse_ap(precursor):
 
     return ''.join(parsed), ';'.join(mods), ';'.join(sites), charge, decoy
 
-def get_x_tandem_score(df: pd.DataFrame) -> np.ndarray:
-    b = df['hits_b'].astype('int').apply(lambda x: np.math.factorial(x)).values
-    y = df['hits_y'].astype('int').apply(lambda x: np.math.factorial(x)).values
-    x_tandem = np.log(b.astype('float')*y.astype('float')*df['fragments_matched_int_sum'].values)
-
-    x_tandem[x_tandem==-np.inf] = 0
-
-    return x_tandem
-
 class AlphaPeptReader(PSMReaderBase):
     def __init__(self,
         *,
@@ -78,10 +65,7 @@ class AlphaPeptReader(PSMReaderBase):
             keep_decoy = keep_decoy,
             **kwargs,
         )
-        if fdr <= 0.1:
-            self.hdf_dataset = 'peptide_fdr'
-        else:
-            self.hdf_dataset = 'second_search'
+        self.hdf_dataset = 'identifications'
 
     def _init_column_mapping(self):
         self.column_mapping = psm_reader_yaml[
@@ -104,9 +88,6 @@ class AlphaPeptReader(PSMReaderBase):
                 df['scan_no'] = df['scan_no'].astype('int')
                 df['raw_idx'] = df['scan_no']-1 # if thermo, use scan-1 as spec_idx
             df['charge'] = df['charge'].astype(int)
-
-            if 'score' not in df.columns:
-                df['score'] = get_x_tandem_score(df)
         return df
     
     def _load_modifications(self, df: pd.DataFrame):
